Makefile: remove generated boards.cfg within make distclean

Signed-off-by: Roger Meier <roger@bufferoverflow.ch>
Reviewed-by: Masahiro Yamada <yamada.m@jp.panasonic.com>
Tested-by: Masahiro Yamada <yamada.m@jp.panasonic.com>
Cc: Tom Rini <trini@ti.com>
Cc: Wolfgang Denk <wd@denx.de>
Cc: Simon Glass <sjg@chromium.org>
diff --git a/MAKEALL b/MAKEALL
index 929fe88..392ea8d 100755
--- a/MAKEALL
+++ b/MAKEALL
@@ -658,7 +658,7 @@
 		MAKE="${MAKE} O=${output_dir}"
 	fi
 
-	${MAKE} distclean >/dev/null
+	${MAKE} mrproper >/dev/null
 
 	echo "Building ${target} board..."
 	${MAKE} -s ${target}_defconfig >/dev/null
diff --git a/Makefile b/Makefile
index b5b3560..0f82fc2 100644
--- a/Makefile
+++ b/Makefile
@@ -1289,6 +1289,7 @@
 		-o -name '.*.rej' -o -name '*%' -o -name 'core' \
 		-o -name '*.pyc' \) \
 		-type f -print | xargs rm -f
+	@rm -f boards.cfg
 
 backup:
 	F=`basename $(srctree)` ; cd .. ; \
diff --git a/tools/buildman/builder.py b/tools/buildman/builder.py
index d5b8454..a555bd8 100644
--- a/tools/buildman/builder.py
+++ b/tools/buildman/builder.py
@@ -308,7 +308,7 @@
         Args:
             commit: Commit object that is being built
             brd: Board object that is being built
-            stage: Stage that we are at (distclean, config, build)
+            stage: Stage that we are at (mrproper, config, build)
             cwd: Directory where make should be run
             args: Arguments to pass to make
             kwargs: Arguments to pass to command.RunPipe()
diff --git a/tools/buildman/builderthread.py b/tools/buildman/builderthread.py
index 32297e2..8214662 100644
--- a/tools/buildman/builderthread.py
+++ b/tools/buildman/builderthread.py
@@ -91,7 +91,7 @@
             commit: Commit object that is being built
             brd: Board object that is being built
             stage: Stage of the build. Valid stages are:
                         distclean - can be called to clean source
                         config - called to configure for a board
                         build - the main make invocation - it does the build
             args: A list of arguments to pass to 'make'
@@ -200,8 +200,8 @@
 
                 # If we need to reconfigure, do that now
                 if do_config:
-                    result = self.Make(commit, brd, 'distclean', cwd,
-                            'distclean', *args, env=env)
+                    result = self.Make(commit, brd, 'mrproper', cwd,
+                            'mrproper', *args, env=env)
                     result = self.Make(commit, brd, 'config', cwd,
                             *(args + config_args), env=env)
                     config_out = result.combined
@@ -91,7 +91,7 @@
             brd: Board object that is being built
             stage: Stage of the build. Valid stages are:
-                        distclean - can be called to clean source
+                        mrproper - can be called to clean source
                         config - called to configure for a board
                         build - the main make invocation - it does the build